# -*- coding: utf-8 -*-
__version__ = '1.6'
__title__ = 'api4jenkins'
__description__ = 'Jenkins Python Client'
__url__ = 'https://github.com/joelee2012/api4jenkins'
__author__ = 'Joe Lee'
__author_email__ = 'lj_2005@163.com'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2021 Joe Lee'
__documentation__ = 'https://api4jenkins.readthedocs.io'
